Package: pQTLdata
Title: A Collection of Proteome Panels and Metadata
Version: 0.6
Date: 2026-3-9
Authors@R: c(
    person("Jing Hua", "Zhao", , "jinghuazhao@hotmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-1463-5870", "0000-0003-4930-3582")),
    person("Uwe", "Ligges", role = "ctb"),
    person("Benjamin", "Altmann", role = "ctb"),
    person("Brian", "Ripley", role = "ctb")
    )
Description: It aggregates protein panel data and metadata for protein quantitative
 trait locus (pQTL) analysis using 'pQTLtools' (<https://jinghuazhao.github.io/pQTLtools/>).
 The package includes data from affinity-based panels such as 'Olink' (<https://olink.com/>) 
 and 'SomaScan' (<https://somalogic.com/>), as well as mass spectrometry-based panels from
 'CellCarta' (<https://cellcarta.com/>), 'Seer' (<https://seer.bio/>) and 'SWATH-MS'
 (<doi:10.15252/msb.20178126>). The metadata encompasses updated annotations
 and publication details.
License: MIT + file LICENSE
URL: https://jinghuazhao.github.io/pQTLdata/,
        https://github.com/jinghuazhao/pQTLdata
BugReports: https://github.com/jinghuazhao/pQTLdata/issues
Depends: R (>= 3.5.0)
Imports: knitr, Rdpack
RdMacros: Rdpack
Suggests: dplyr, grid, EnsDb.Hsapiens.v75, ensembldb, IRanges,
        org.Hs.eg.db, S4Vectors, VennDiagram
VignetteBuilder: knitr
LazyData: Yes
LazyLoad: Yes
LazyDataCompression: xz
NeedsCompilation: no
Encoding: UTF-8
RoxygenNote: 7.3.3
Packaged: 2026-03-09 11:38:17 UTC; jhz22
Author: Jing Hua Zhao [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-1463-5870>, 0000-0003-4930-3582),
  Uwe Ligges [ctb],
  Benjamin Altmann [ctb],
  Brian Ripley [ctb]
Maintainer: Jing Hua Zhao <jinghuazhao@hotmail.com>
Repository: CRAN
Date/Publication: 2026-03-09 12:40:02 UTC
Built: R 4.6.0; ; 2026-04-26 04:33:19 UTC; unix
